@@ -89,29 +89,11 @@ path_wd <- function(..., ext = "") {
 #'   calls `path_expand()` (literally) and `path_norm()` (effectively).
 #' @export
 path_real <- function(path) {
-  path <- enc2utf8(path)
+  path <- enc2utf8(as.character(path))
   old <- path_expand(path)
 
-  # We need to convert all paths to absolute paths, but _not_ to normalize
-  # them, so we cannot use `path_abs()`.
-  is_abs <- is_absolute_path(path)
-  old[!is_abs] <- path(getwd(), path[!is_abs])
-
   is_missing <- is.na(path)
-  exists <- file_exists(path) == TRUE
-
-  # Realize all paths which fully exist
-  old[!is_missing & exists] <- .Call(fs_realize_, old[!is_missing & exists])
-
-  # Handle paths which only partially exist
-  realize_one <- function(splits) {
-    paths <- Reduce(fs::path, splits, accumulate = TRUE)
-    last_link <- which.max(is_link(paths))
-    path(.Call(fs_realize_, paths[last_link]), path_join(splits[seq(last_link + 1, length(splits))]))
-  }
-
-  partial <- !is_missing & !exists
-  old[partial] <- vapply(path_split(old[partial]), realize_one, character(1))
+  old[!is_missing] <- .Call(fs_realize_, old[!is_missing])
 
   path_tidy(old)
 }
@@ -128,7 +110,7 @@ path_real <- function(path) {
 #' @template fs
 #' @export
 path_tidy <- function(path) {
-  path <- as.character(path)
+  path <- enc2utf8(as.character(path))
   new_fs_path(.Call(fs_tidy_, path))
 }
 
@@ -155,8 +137,8 @@ path_join <- function(parts) {
   if (length(parts) == 0) {
     return(path_tidy(""))
   }
-  if (is.character(parts)) {
-    return(path_tidy(.Call(fs_path_, as.list(enc2utf8(parts)), "")))
+  if (!is.list(parts)) {
+    return(path_tidy(.Call(fs_path_, as.list(enc2utf8(as.character(parts))), "")))
   }
   path_tidy(vapply(parts, path_join, character(1)))
 }
